"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = exports.buildStopEmission = exports.buildStartEmission = exports.buildCloseFeature = exports.buildOpenFeature = exports.buildForeground = exports.buildBackground = exports.setBackgroundIsVisible = exports.setForegroundIsVisible = exports.setBackgroundIsEnabled = exports.setForegroundIsEnabled = exports.actionTypes = exports.selectBackground = exports.selectForeground = exports.setStopEmission = exports.setStartEmission = exports.setCloseFeature = exports.setOpenFeature = exports.setBackground = exports.setForeground = exports.selectCommandsArray = exports.selectCommands = void 0;

var _toolkit = require("@reduxjs/toolkit");

var _keymirror = _interopRequireDefault(require("keymirror"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const actionTypes = (0, _keymirror.default)({
  FOREGROUND: null,
  BACKGROUND: null,
  START_EMISSION: null,
  STOP_EMISSION: null,
  OPEN_FEATURE: null,
  CLOSE_FEATURE: null
});
exports.actionTypes = actionTypes;

const buildStartEmission = moduleGuid => ({
  action: {
    type: actionTypes.START_EMISSION,
    sink: 'MODULE',
    moduleGuid
  }
});

exports.buildStartEmission = buildStartEmission;

const buildStopEmission = moduleGuid => ({
  action: {
    type: actionTypes.STOP_EMISSION,
    sink: 'MODULE',
    moduleGuid
  }
});

exports.buildStopEmission = buildStopEmission;

const buildForeground = moduleGuid => ({
  index: 0,
  isEnabled: false,
  isVisible: true,
  label: 'Foreground',
  tooltip: 'bring module to foreground',
  iconPath: 'M2,2H16V16H2V2M22,8V22H8V18H10V20H20V10H18V8H22Z',
  action: {
    type: actionTypes.FOREGROUND,
    sink: 'MODULE',
    moduleGuid
  }
});

exports.buildForeground = buildForeground;

const buildBackground = moduleGuid => ({
  index: 1,
  invocationGuid: null,
  isEnabled: true,
  isVisible: true,
  label: 'Background',
  tooltip: 'send module to background',
  iconPath: 'M2,2H16V16H2V2M22,8V22H8V18H18V8H22M4,4V14H14V4H4Z',
  action: {
    type: actionTypes.BACKGROUND,
    sink: 'MODULE',
    moduleGuid
  }
});

exports.buildBackground = buildBackground;

const buildOpenFeature = moduleGuid => ({
  index: 2,
  isEnabled: true,
  isVisible: false,
  label: null,
  tooltip: null,
  iconPath: null,
  action: {
    moduleGuid,
    type: actionTypes.OPEN_FEATURE,
    sink: 'MODULE',
    featureGuid: null
  }
});

exports.buildOpenFeature = buildOpenFeature;

const buildCloseFeature = moduleGuid => ({
  index: 3,
  isEnabled: true,
  isVisible: false,
  label: null,
  tooltip: null,
  iconPath: null,
  action: {
    moduleGuid,
    type: actionTypes.CLOSE_FEATURE,
    sink: 'MODULE',
    featureGuid: null
  }
});

exports.buildCloseFeature = buildCloseFeature;
const slice = (0, _toolkit.createSlice)({
  name: 'commands',
  initialState: {
    foreground: null,
    background: null,
    openFeature: null,
    closeFeature: null,
    startEmission: null,
    stopEmission: null
  },
  reducers: {
    setForeground: (state, action) => {
      const stateRef = state;
      stateRef.foreground = action.payload;
    },
    setBackground: (state, action) => {
      const stateRef = state;
      stateRef.background = action.payload;
    },
    setForegroundIsVisible: (state, action) => {
      const stateRef = state;
      stateRef.foreground.isVisible = action.payload;
    },
    setBackgroundIsVisible: (state, action) => {
      const stateRef = state;
      stateRef.background.isVisible = action.payload;
    },
    setForegroundIsEnabled: (state, action) => {
      const stateRef = state;
      stateRef.foreground.isEnabled = action.payload;
    },
    setBackgroundIsEnabled: (state, action) => {
      const stateRef = state;
      stateRef.background.isEnabled = action.payload;
    },
    setOpenFeature: (state, action) => {
      const stateRef = state;
      stateRef.openFeature = action.payload;
    },
    setCloseFeature: (state, action) => {
      const stateRef = state;
      stateRef.closeFeature = action.payload;
    },
    setStartEmission: (state, action) => {
      const stateRef = state;
      stateRef.startEmission = action.payload;
    },
    setStopEmission: (state, action) => {
      const stateRef = state;
      stateRef.stopEmission = action.payload;
    }
  }
});
const {
  setForeground,
  setBackground,
  setOpenFeature,
  setCloseFeature,
  setStartEmission,
  setStopEmission,
  setForegroundIsVisible,
  setBackgroundIsVisible,
  setForegroundIsEnabled,
  setBackgroundIsEnabled
} = slice.actions;
exports.setBackgroundIsEnabled = setBackgroundIsEnabled;
exports.setForegroundIsEnabled = setForegroundIsEnabled;
exports.setBackgroundIsVisible = setBackgroundIsVisible;
exports.setForegroundIsVisible = setForegroundIsVisible;
exports.setStopEmission = setStopEmission;
exports.setStartEmission = setStartEmission;
exports.setCloseFeature = setCloseFeature;
exports.setOpenFeature = setOpenFeature;
exports.setBackground = setBackground;
exports.setForeground = setForeground;

const selectForeground = state => state.commands.foreground;

exports.selectForeground = selectForeground;

const selectBackground = state => state.commands.background;

exports.selectBackground = selectBackground;

const selectCommands = state => state.commands;

exports.selectCommands = selectCommands;

const selectCommandsArray = state => [state.commands.foreground, state.commands.background, state.commands.openFeature, state.commands.closeFeature, state.commands.startEmission, state.commands.stopEmission];

exports.selectCommandsArray = selectCommandsArray;
var _default = slice.reducer;
exports.default = _default;